@@ -21,6 +21,8 @@
 
 from collections import namedtuple
 
+from neo4j._exceptions import BoltProtocolError
+
 BOLT_VERSION_1 = 1
 BOLT_VERSION_2 = 2
 BOLT_VERSION_3 = 3
@@ -45,7 +47,9 @@ class ResultSummary:
     #: Dictionary of parameters passed with the statement.
     parameters = None
 
-    #: A string that describes the type of query (``'r'`` = read-only, ``'rw'`` = read/write).
+    #: A string that describes the type of query
+    # ``'r'`` = read-only, ``'rw'`` = read/write, ``'w'`` = write-onlye,
+    # ``'s'`` = schema.
     query_type = None
 
     #: A :class:`neo4j.SummaryCounters` instance. Counters for operations the query triggered.
@@ -70,12 +74,19 @@ class ResultSummary:
     #: Unlike failures or errors, notifications do not affect the execution of a statement.
     notifications = None
 
-    def __init__(self, **metadata):
+    def __init__(self, address, **metadata):
         self.metadata = metadata
         self.server = metadata.get("server")
         self.database = metadata.get("db")
         self.query = metadata.get("query")
         self.parameters = metadata.get("parameters")
+        if "type" in metadata:
+            self.query_type = metadata["type"]
+            if self.query_type not in ["r", "w", "rw", "s"]:
+                raise BoltProtocolError(
+                    "Unexpected query type '%s' received from server. Consider "
+                    "updating the driver.", address
+                )
         self.query_type = metadata.get("type")
         self.plan = metadata.get("plan")
         self.profile = metadata.get("profile")
@@ -129,24 +140,52 @@ class SummaryCounters:
     #:
     system_updates = 0
 
+    _contains_updates = None
+    _contains_system_updates = None
+
     def __init__(self, statistics):
+        key_to_attr_name = {
+            "nodes-created": "nodes_created",
+            "nodes-deleted": "nodes_deleted",
+            "relationships-created": "relationships_created",
+            "relationships-deleted": "relationships_deleted",
+            "properties-set": "properties_set",
+            "labels-added": "labels_added",
+            "labels-removed": "labels_removed",
+            "indexes-added": "indexes_added",
+            "indexes-removed": "indexes_removed",
+            "constraints-added": "constraints_added",
+            "constraints-removed": "constraints_removed",
+            "system-updates": "system_updates",
+            "contains-updates": "_contains_updates",
+            "contains-system-updates": "_contains_system_updates",
+        }
         for key, value in dict(statistics).items():
-            key = key.replace("-", "_")
-            setattr(self, key, value)
+            attr_name = key_to_attr_name.get(key)
+            if attr_name:
+                setattr(self, attr_name, value)
 
     def __repr__(self):
         return repr(vars(self))
 
     @property
     def contains_updates(self):
-        """True if any of the counters except for system_updates, are greater than 0. Otherwise False."""
-        return bool(self.nodes_created or self.nodes_deleted or
-                    self.relationships_created or self.relationships_deleted or
-                    self.properties_set or self.labels_added or self.labels_removed or
-                    self.indexes_added or self.indexes_removed or
-                    self.constraints_added or self.constraints_removed)
+        """True if any of the counters except for system_updates, are greater
+        than 0. Otherwise False."""
+        if self._contains_updates is not None:
+            return self._contains_updates
+        return bool(
+            self.nodes_created or self.nodes_deleted
+            or self.relationships_created or self.relationships_deleted
+            or self.properties_set or self.labels_added
+            or self.labels_removed or self.indexes_added
+            or self.indexes_removed or self.constraints_added
+            or self.constraints_removed
+        )
 
     @property
     def contains_system_updates(self):
         """True if the system database was updated, otherwise False."""
+        if self._contains_system_updates is not None:
+            return self._contains_system_updates
         return self.system_updates > 0
